@@ -3,6 +3,7 @@ Configuration file for the Sphinx documentation builder.
 
 isort:skip_file
 """
+
 # flake8: NOQA: E402
 
 # -- stdlib imports ------------------------------------------------------------
@@ -14,7 +15,7 @@ from packaging.version import Version
 
 project = "Parfive"
 author = "Stuart Mumford and Contributors"
-copyright = "{}, {}".format(datetime.datetime.now().year, author)
+copyright = f"{datetime.datetime.now().year}, {author}"
 
 # The full version, including alpha/beta/rc tags
 release = __version__
@@ -82,9 +83,9 @@ typehints_defaults = "comma"
 
 # Example configuration for intersphinx: refer to the Python standard library.
 intersphinx_mapping = {
-    "https://docs.python.org/": None,
-    "https://docs.aiohttp.org/en/stable": None,
-    "https://aioftp.readthedocs.io/": None,
+    "python": ("https://docs.python.org/", None),
+    "aiohttp": ("https://docs.aiohttp.org/en/stable", None),
+    "aioftp": ("https://aioftp.readthedocs.io/", None),
 }
 
 # -- Options for HTML output ---------------------------------------------------
@@ -109,6 +110,13 @@ html_css_files = [
     "css/contributors.css",
 ]
 
+html_js_files = [
+    (
+        "//gc.zgo.at/count.js",
+        {"async": "async", "data-goatcounter": "https://parfive.goatcounter.com/count"},
+    )
+]
+
 # Render inheritance diagrams in SVG
 graphviz_output_format = "svg"
 
