@@ -3,6 +3,8 @@ import signal
 import asyncio
 import logging
 import pathlib
+import warnings
+import threading
 import contextlib
 import urllib.parse
 from typing import Union, Callable, Optional
@@ -75,9 +77,8 @@ class Downloader:
         max_splits: int = 5,
         progress: bool = True,
         overwrite: Union[bool, Literal["unique"]] = False,
-        config: SessionConfig = None,
+        config: Optional[SessionConfig] = None,
     ):
-
         self.config = DownloaderConfig(
             max_conn=max_conn,
             max_splits=max_splits,
@@ -151,9 +152,11 @@ class Downloader:
     def enqueue_file(
         self,
         url: str,
-        path: Union[str, os.PathLike] = None,
-        filename: Union[str, Callable[[str, Optional[aiohttp.ClientResponse]], os.PathLike]] = None,
-        overwrite: Union[bool, Literal["unique"]] = None,
+        path: Optional[Union[str, os.PathLike]] = None,
+        filename: Optional[
+            Union[str, Callable[[str, Optional[aiohttp.ClientResponse]], os.PathLike]]
+        ] = None,
+        overwrite: Optional[Union[bool, Literal["unique"]]] = None,
         **kwargs,
     ):
         """
@@ -222,6 +225,14 @@ class Downloader:
     def _add_shutdown_signals(loop, task):
         if os.name == "nt":
             return
+
+        if threading.current_thread() != threading.main_thread():
+            warnings.warn(
+                "This download has been started in a thread which is not the main thread. You will not be able to interrupt the download.",
+                UserWarning,
+            )
+            return
+
         for sig in (signal.SIGINT, signal.SIGTERM):
             loop.add_signal_handler(sig, task.cancel)
 
@@ -607,6 +618,8 @@ class Downloader:
             await asyncio.gather(*tasks)
             # join() waits till all the items in the queue have been processed
             await downloaded_chunk_queue.join()
+            for callback in self.config.done_callbacks:
+                callback(filepath, url, None)
             return str(filepath)
 
         except (Exception, asyncio.CancelledError) as e:
@@ -622,6 +635,8 @@ class Downloader:
             # computed the filepath, so we have no file to cleanup
             if filepath is not None:
                 remove_file(filepath)
+            for callback in self.config.done_callbacks:
+                callback(filepath, url, e)
             raise FailedDownload(filepath_partial, url, e)
 
         finally:
@@ -826,6 +841,10 @@ class Downloader:
 
                     await asyncio.gather(*download_workers)
                     await downloaded_chunks_queue.join()
+
+                    for callback in self.config.done_callbacks:
+                        callback(filepath, url, None)
+
                     return str(filepath)
 
         except (Exception, asyncio.CancelledError) as e:
@@ -836,6 +855,11 @@ class Downloader:
             # computed the filepath, so we have no file to cleanup
             if filepath is not None:
                 remove_file(filepath)
+                filepath = None
+
+            for callback in self.config.done_callbacks:
+                callback(filepath, url, e)
+
             raise FailedDownload(filepath_partial, url, e)
 
         finally:
